@@ -51,12 +51,6 @@ CHECKSUMS_URLS = (
 )
 
 HTTP_HEADERS = {'User-Agent': 'F-Droid'}
-
-CACHEDIR = Path.home() / '.cache/sdkmanager'
-ANDROID_SDK_ROOT = os.getenv(
-    'ANDROID_SDK_ROOT', os.getenv('ANDROID_HOME', '/opt/android-sdk')
-)
-
 BUILD_REGEX = re.compile(r'[1-9][0-9]{6}')
 NDK_RELEASE_REGEX = re.compile(r'r[1-9][0-9]?[a-z]?(?:-(?:rc|beta)[0-9]+)?')
 M2REPOSITORY_REVISION_REGEX = re.compile(r'android_m2repository_r([0-9]+)\.zip')
@@ -526,8 +520,38 @@ revisions = {}
 platform_versions = {}
 
 
+def get_android_home():
+    """Get the pathlib.Path that is the base dir of the Android SDK home
+
+    This first tries the canonical ANDROID_HOME, then tries the
+    deprecated ANDROID_SDK_ROOT, then falls back to a sensible,
+    hard-coded default.
+
+    https://developer.android.com/studio/command-line/variables#envar
+
+    """
+    path = os.getenv('ANDROID_HOME', os.getenv('ANDROID_SDK_ROOT', '/opt/android-sdk'))
+    if not path:
+        print('ERROR: ANDROID_HOME is set to blank!')
+        sys.exit(1)
+
+    android_home = Path(path)
+    if not android_home.parent.exists():
+        raise FileNotFoundError('ANDROID_HOME "%s" does not exist!' % android_home)
+    android_home.mkdir(exist_ok=True)
+
+    return android_home
+
+
+def get_cachedir():
+    cachedir = Path.home() / '.cache/sdkmanager'
+    cachedir.mkdir(mode=0o0700, parents=True, exist_ok=True)
+    return cachedir
+
+
 def verify(filename):
-    keyring = CACHEDIR / 'keyring.gpg'
+    cachedir = get_cachedir()
+    keyring = cachedir / 'keyring.gpg'
     with io.BytesIO(base64.b64decode(KEYRING_GPG_GZ_BASE64)) as infp:
         with gzip.GzipFile(fileobj=infp) as gzipfp:
             with keyring.open('wb') as fp:
@@ -560,7 +584,7 @@ def download_file(url, local_filename=None):
     """
     filename = os.path.basename(urlparse(url).path)
     if local_filename is None:
-        local_filename = CACHEDIR / filename
+        local_filename = get_cachedir() / filename
     print('Downloading', url, 'into', local_filename)
     r = requests.get(url, stream=True, allow_redirects=True, headers=HTTP_HEADERS)
     r.raise_for_status()
@@ -813,8 +837,9 @@ def parse_repositories_cfg(f):
 # TODO allow : and - as separator, e.g. ndk-22.1.7171670
 # only use android-sdk-transparency-log as source
 def build_package_list(use_net=False):
-    cached_checksums = CACHEDIR / 'checksums.json'
-    cached_checksums_signature = CACHEDIR / (cached_checksums.name + '.asc')
+    cachedir = get_cachedir()
+    cached_checksums = cachedir / 'checksums.json'
+    cached_checksums_signature = cachedir / (cached_checksums.name + '.asc')
     if cached_checksums.exists() and cached_checksums_signature.exists():
         verify(cached_checksums)
         with cached_checksums.open() as fp:
@@ -898,7 +923,6 @@ def licenses():
     https://cs.android.com/android-studio/platform/tools/base/+/mirror-goog-studio-main:repository/src/main/java/com/android/repository/api/License.java
 
     """
-    global ANDROID_SDK_ROOT
     known_licenses = {
         'android-sdk-license': '\n8933bad161af4178b1185d1a37fbf41ea5269c55\n\nd56f5187479451eabf01fb78af6dfcb131a6481e\n24333f8a63b6825ea9c5514f83c2829b004d1fee',
         'android-sdk-preview-license': '\n84831b9409646a918e30573bab4c9c91346d8abd\n',
@@ -912,7 +936,7 @@ def licenses():
                 known_license_hashes.add(license)
 
     found_license_hashes = set()
-    licenses_dir = Path(ANDROID_SDK_ROOT) / 'licenses'
+    licenses_dir = get_android_home() / 'licenses'
     for f in licenses_dir.glob('*'):
         with f.open() as fp:
             for license in fp.read().strip().split('\n'):
@@ -944,7 +968,7 @@ def licenses():
                             fp.write(known)
 
 
-def install(to_install):
+def install(to_install, android_home=None):
     """Install specified packages, including downloading them as needed
 
     Certain packages are installed into versioned sub-directories
@@ -957,9 +981,17 @@ def install(to_install):
     to_install
         A single package or list of packages to install.
 
+    android_home
+        Optionally provide the ANDROID_HOME path as the install location.
+
     """
     global packages
 
+    if android_home is None:
+        android_home = get_android_home()
+    if isinstance(android_home, str):
+        android_home = Path(android_home)
+
     if isinstance(to_install, str):
         to_install = [to_install]
     for package in to_install:
@@ -972,13 +1004,13 @@ def install(to_install):
             name = key[0]
 
         if len(key) > 1:
-            install_dir = ANDROID_SDK_ROOT / INSTALL_DIRS[name].format(revision=key[-1])
+            install_dir = android_home / INSTALL_DIRS[name].format(revision=key[-1])
         else:
-            install_dir = ANDROID_SDK_ROOT / INSTALL_DIRS[name]
+            install_dir = android_home / INSTALL_DIRS[name]
         if install_dir.exists():
             continue
 
-        zipball = CACHEDIR / os.path.basename(url)
+        zipball = get_cachedir() / os.path.basename(url)
         if not zipball.exists():
             download_file(url, zipball)
 
@@ -1091,17 +1123,6 @@ def list():
 
 
 def main():
-    global CACHEDIR, ANDROID_SDK_ROOT, ANDROID_NDK_ROOT
-
-    if ANDROID_SDK_ROOT:
-        ANDROID_SDK_ROOT = Path(ANDROID_SDK_ROOT)
-    if not ANDROID_SDK_ROOT.parent.exists():
-        print(__file__, 'writes into $ANDROID_SDK_ROOT but it does not exist!')
-        sys.exit(1)
-    ANDROID_SDK_ROOT.mkdir(exist_ok=True)
-
-    CACHEDIR.mkdir(mode=0o0700, parents=True, exist_ok=True)
-
     parser = argparse.ArgumentParser()
     # commands
     parser.add_argument("--install", action="store_true")
